@@ -7,17 +7,17 @@ my $SPEC = { };
 
 
 sub TIESCALAR {
-    my ($class, $container, $ns, $new, $ctor, $setter, $singleton) = @_;
+    my ($class, $container, $ns, $new, $ctor, $ctor_passthru, $setter, $singleton) = @_;
     my $scalar = '';
     my $self = bless(\$scalar, $class);
-    $SPEC->{refaddr($self)} = [ { }, $container, $ns, $new, $ctor, $setter, $singleton ];
+    $SPEC->{refaddr($self)} = [ { }, $container, $ns, $new, $ctor, $ctor_passthru, $setter, $singleton ];
     return $self;
 }
 
 sub FETCH {
     my ($self) = @_;
     my $spec = $SPEC->{refaddr($self)};
-    my ($tmp, $container, $ns, $new, $ctor, $setter, $singleton) = @$spec;
+    my ($tmp, $container, $ns, $new, $ctor, $ctor_passthru, $setter, $singleton) = @$spec;
     if ($singleton) {
         # short circuit the process
         if (exists $tmp->{last_inst}) {
@@ -29,7 +29,11 @@ sub FETCH {
     
     # constructor
     # -----------
-    if (ref($ctor) eq 'HASH') {
+    if ($ctor_passthru) {
+        # passthru forces the constructor args as is
+        $tmp->{last_inst} = $ns->$new($ctor);
+    }
+    elsif (ref($ctor) eq 'HASH') {
         # pass as hash
         $tmp->{last_inst} = $ns->$new(%$ctor);
     }
@@ -44,7 +48,7 @@ sub FETCH {
     # set setter args
     # ---------------
     while (my ($k,$v) = each(%$setter)) {
-        $container->wire($v);
+        $container->wire($container, $v);
         $tmp->{last_inst}->$k($v);
     }
     return $tmp->{last_inst};
